@@ -273,7 +273,7 @@ class TypesButtons:
     CANCEL_TRY_AGAIN_CONTINUE = 6
 
 
-class Button:
+class Buttons:
     OK = 1
     CANCEL = 2
     ABORT = 3
